@@ -9,7 +9,7 @@ import six
 from .mixins import HashableMixin, SerializableMixin
 from .serialize import FlatData, VarInt
 
-from .tools import Bits, StringIO, icmp, lookahead, list, tuple
+from .tools import Bits, BytesIO, icmp, lookahead, list, tuple
 
 __all__ = (
     'BaseAuthTreeLink',
@@ -32,13 +32,20 @@ class BaseAuthTreeLink(HashableMixin):
     __slots__ = 'prefix node _hash _count _size'.split()
 
     def __init__(self, prefix, node=None, hash=None, count=None, size=None, *args, **kwargs):
+        # Coerce the prefix from whatever type it is into a Bits
+        # field. This allows passing binary strings or any type
+        # understood by the Bits constructor.
         if not isinstance(prefix, Bits):
             if isinstance(prefix, six.binary_type):
                 prefix = Bits(bytes=prefix)
             else:
                 prefix = Bits(prefix)
+        # It is permissible to provide just a node or its hash as the
+        # 2nd positional argument.
         if isinstance(node, numbers.Integral):
             node, hash = hash, node
+        # Count and size must be provided for pruned links, otherwise
+        # it can of course be extracted from the node object.
         if hasattr(node, 'count'): count = node.count
         if hasattr(node, 'size'):  size  = node.size
         super(BaseAuthTreeLink, self).__init__(*args, **kwargs)
@@ -47,22 +54,26 @@ class BaseAuthTreeLink(HashableMixin):
 
     @property
     def pruned(self):
+        "Returns True if the link does not point to a node object."
         return self.node is None
 
     @property
     def count(self):
+        "The number of items, pruned or otherwise, contained by this branch."
         if getattr(self, '_count', None) is None:
             self._count = getattr(self.node, 'count', 0)
         return self._count
 
     @property
     def size(self):
+        "The canonical serialized size of this branch."
         if getattr(self, '_size', None) is None:
             self._size = getattr(self.node, 'size', 0)
         return self._size
 
     @property
     def length(self):
+        "The number of non-pruned items in this branch."
         if self.pruned:
             return 0
         return self.node.length
@@ -111,7 +122,7 @@ class ComposableAuthTreeLink(BaseAuthTreeLink):
                 hash_ = self.compressor(b''.join([
                     self.compressor(bit and b'\x04\x00' or b'\x01\x00').digest(),
                     hash_])).digest()
-            hash_ = self.compressor.deserialize(StringIO(hash_))
+            hash_ = self.compressor.deserialize(BytesIO(hash_))
         return hash_
 
 class PatriciaAuthTreeLink(BaseAuthTreeLink):
@@ -166,7 +177,7 @@ class BaseAuthTreeNode(SerializableMixin, HashableMixin):
         attr_class = cls._get_attr_class(attr)
         deserialize = getattr(attr_class, 'deserialize', None)
         if six.callable(deserialize):
-            return deserialize(StringIO(string))
+            return deserialize(BytesIO(string))
         else:
             return attr_class(string)
     @classmethod
@@ -589,7 +600,7 @@ class BaseAuthTreeNode(SerializableMixin, HashableMixin):
             remaining_key = key[len(prefix):]
             idx = bisect_left(old_node.children, link_class(prefix=remaining_key[:1]))
 
-            if idx in xrange(len(old_node.children)):
+            if idx in range(len(old_node.children)):
                 common_prefix = commonprefix([old_node.children[idx].prefix, remaining_key])
             else:
                 common_prefix = Bits()
@@ -696,7 +707,7 @@ class BaseAuthTreeNode(SerializableMixin, HashableMixin):
         else:
             remaining_key = key[len(prefix):]
             idx = bisect_left(old_node.children, link_class(prefix=remaining_key[:1]))
-            if idx not in xrange(len(old_node.children)):
+            if idx not in range(len(old_node.children)):
                 return 0
 
             link = old_node.children[idx]
@@ -826,3 +837,5 @@ class BasePatriciaAuthTree(BaseAuthTreeNode):
     link_class = PatriciaAuthTreeLink
 class MemoryPatriciaAuthTree(BasePatriciaAuthTree):
     pass
+
+# End of File
