@@ -137,7 +137,7 @@ class Input(SerializableMixin):
 
 class Transaction(SerializableMixin, HashableMixin):
     def __init__(self, version=1, inputs=None, outputs=None, lock_time=0,
-                 reference_height=0, *args, **kwargs):
+                 lock_height=0, *args, **kwargs):
         if inputs is None: inputs = ()
         if outputs is None: outputs = ()
         super(Transaction, self).__init__(*args, **kwargs)
@@ -147,7 +147,7 @@ class Transaction(SerializableMixin, HashableMixin):
         getattr(self, 'outputs_create', lambda:setattr(self, 'outputs', list()))()
         self.outputs.extend(outputs)
         self.lock_time = lock_time
-        self.reference_height = reference_height
+        self.lock_height = lock_height
 
     @classmethod
     def get_input_class(cls):
@@ -164,8 +164,8 @@ class Transaction(SerializableMixin, HashableMixin):
         result += serialize_iterator(self.inputs, lambda i:i.serialize())
         result += serialize_iterator(self.outputs, lambda o:o.serialize())
         result += pack('<I', self.lock_time)
-        if self.version==2:
-            result += pack('<I', self.reference_height)
+        if not (self.version == 1 and len(self.inputs) == 1 and self.inputs[0].is_coinbase):
+            result += pack('<I', self.lock_height)
         return result
     @classmethod
     def deserialize_input(cls, file_, *args, **kwargs):
@@ -182,8 +182,8 @@ class Transaction(SerializableMixin, HashableMixin):
         initargs['inputs'] = list(deserialize_iterator(file_, lambda f:cls.deserialize_input(f)))
         initargs['outputs'] = list(deserialize_iterator(file_, lambda f:cls.deserialize_output(f)))
         initargs['lock_time'] = unpack('<I', file_.read(4))[0]
-        if initargs['version'] in (2,):
-            initargs['reference_height'] = unpack('<I', file_.read(4))[0]
+        if not (self.version == 1 and len(self.inputs) == 1 and self.inputs[0].is_coinbase):
+            initargs['lock_height'] = unpack('<I', file_.read(4))[0]
         return cls(**initargs)
 
     @property
@@ -191,15 +191,16 @@ class Transaction(SerializableMixin, HashableMixin):
         return 1==len(self.inputs) and not self.inputs[0].is_coinbase
 
     def __eq__(self, other):
-        return all((self.version          == other.version,
-                    self.lock_time        == other.lock_time,
-                    self.reference_height == other.reference_height,
+        return all((self.version     == other.version,
+                    self.lock_time   == other.lock_time,
+                    self.lock_height == other.lock_height,
                     icmp(iter(self.inputs),  iter(other.inputs))  == 0,
                     icmp(iter(self.outputs), iter(other.outputs)) == 0))
     def __repr__(self):
-        reference_height_str = (self.version in (2,)
-            and ', reference_height=%d' % self.reference_height
-             or '')
+        if self.version == 1 and len(self.inputs) == 1 and self.inputs[0].is_coinbase:
+            lock_height_str = ''
+        else:
+            lock_height_str = ', lock_height=%d' % self.lock_height
         return ('%s(version=%d, '
                    'inputs=%s, '
                    'outputs=%s, '
@@ -209,7 +210,7 @@ class Transaction(SerializableMixin, HashableMixin):
             repr(self.inputs),
             repr(self.outputs),
             self.lock_time,
-            reference_height_str))
+            lock_height_str))
 
 # ===----------------------------------------------------------------------===
 
@@ -317,4 +318,6 @@ from .hash import hash256
 from .numeric import mpq
 from .script import Script
 from .serialize import LittleCompactSize, FlatData, serialize_iterator, deserialize_iterator
-from .tools import StringIO, icmp, list, target_from_compact, tuple
+from .tools import BytesIO, icmp, list, target_from_compact, tuple
+
+# End of File
