@@ -568,7 +568,7 @@ class ScriptOp(SerializableMixin, six.binary_type):
     def __repr__(self):
         data_str = ''.join([
             'bytes.fromhex(\'',
-            (self.data or '').encode('hex'),
+            (self.data or b'').hex(),
             '\')'])
         if self.opcode>0 and self.opcode<=OP_PUSHDATA4:
             return data_str
@@ -590,7 +590,10 @@ class Script(SerializableMixin, six.binary_type):
                           getattr(self, 'script_op_class', ScriptOp))()
         file_ = BytesIO(self)
         while True:
-            yield script_op_class.deserialize(file_)
+            try:
+                yield script_op_class.deserialize(file_)
+            except EmptyScriptError:
+                break
 
     def serialize(self):
         return b''.join((self,))
@@ -605,7 +608,7 @@ class Script(SerializableMixin, six.binary_type):
         try:
             return u"Script([%s])" % ', '.join(map(repr, self))
         except:
-            return u"Script(\'%s\'.decode(\'hex\'))" % self.encode('hex')
+            return u"Script.fromhex(\'%s\')" % self.hex()
 
 # ===----------------------------------------------------------------------===
 
